"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addChainToAngularJson = exports.setAllCustomWebpackChainingToAngularJson = exports.setCustomWebpackChainingToAngularJson = exports.setAllCustomWebpackBuilderToAngularJson = exports.setCustomWebpackBuilderToAngularJson = void 0;
const _ = require("lodash");
const BUILDERS = {
    'build': 'angular-custom-webpack-chaining:browser',
    'serve': 'angular-custom-webpack-chaining:dev-server',
    'server': 'angular-custom-webpack-chaining:server',
    'test': 'angular-custom-webpack-chaining:karma'
};
const customWebpackPath = (projectName, architect) => {
    return ['projects', projectName, 'architect', architect, 'options', 'customWebpack'];
};
const getConfig = (json, projectName, architect) => {
    return _.get(json, customWebpackPath(projectName, architect));
};
const configExists = (json, projectName, architect) => {
    return !!getConfig(json, projectName, architect);
};
const setConfig = (json, projectName, architect, config) => {
    return _.set(json, customWebpackPath(projectName, architect), config);
};
const setConfigIfNotExists = (json, projectName, architect, config) => {
    if (!configExists(json, projectName, architect))
        setConfig(json, projectName, architect, config);
};
function setCustomWebpackBuilderToAngularJson(host, projectName, architect = BUILDERS['build'], builder = 'browser', webpackConfigPath = './extra-webpack.config.js') {
    return exists(host, 'angular.json', () => {
        const json = JSON.parse(host.read('angular.json').toString('utf-8'));
        _.set(json, ['projects', projectName, 'architect', architect, 'builder'], builder);
        setConfigIfNotExists(json, projectName, architect, { path: webpackConfigPath });
        host.overwrite('angular.json', JSON.stringify(json, null, 2));
        return host;
    });
}
exports.setCustomWebpackBuilderToAngularJson = setCustomWebpackBuilderToAngularJson;
function setAllCustomWebpackBuilderToAngularJson(host, projectName, webpackConfigPath = './extra-webpack.config.js') {
    return exists(host, 'angular.json', () => {
        var _a;
        const json = JSON.parse(host.read('angular.json').toString('utf-8'));
        return Object.keys((_a = _.get(json, ['projects', projectName, 'architect'])) !== null && _a !== void 0 ? _a : [])
            .filter(arch => arch in BUILDERS)
            .reduce((host, architect) => setCustomWebpackBuilderToAngularJson(host, projectName, architect, BUILDERS[architect], webpackConfigPath), host);
    });
}
exports.setAllCustomWebpackBuilderToAngularJson = setAllCustomWebpackBuilderToAngularJson;
function setCustomWebpackChainingToAngularJson(host, projectName, architect = 'build') {
    return exists(host, 'angular.json', () => {
        const json = JSON.parse(host.read('angular.json').toString('utf-8'));
        let config = getConfig(json, projectName, architect);
        setConfig(json, projectName, architect, (config === null || config === void 0 ? void 0 : config.path) ? { chain: [config.path] } : config !== null && config !== void 0 ? config : { chain: [] });
        host.overwrite('angular.json', JSON.stringify(json, null, 2));
        return host;
    });
}
exports.setCustomWebpackChainingToAngularJson = setCustomWebpackChainingToAngularJson;
function setAllCustomWebpackChainingToAngularJson(host, projectName) {
    return exists(host, 'angular.json', () => {
        var _a;
        const json = JSON.parse(host.read('angular.json').toString('utf-8'));
        return Object.keys((_a = _.get(json, ['projects', projectName, 'architect'])) !== null && _a !== void 0 ? _a : [])
            .filter(arch => arch in BUILDERS)
            .reduce((host, architect) => setCustomWebpackChainingToAngularJson(host, projectName, architect), host);
    });
}
exports.setAllCustomWebpackChainingToAngularJson = setAllCustomWebpackChainingToAngularJson;
function addChainToAngularJson(host, projectName, webpackConfigPath, architect = 'build') {
    return exists(host, 'angular.json', () => {
        const json = JSON.parse(host.read('angular.json').toString('utf-8'));
        setConfigIfNotExists(json, projectName, architect, { chain: [] });
        const config = getConfig(json, projectName, architect);
        if ((config === null || config === void 0 ? void 0 : config.chain) && !config.chain.includes(webpackConfigPath)) {
            config.chain.push(webpackConfigPath);
        }
        host.overwrite('angular.json', JSON.stringify(json, null, 2));
        return host;
    });
}
exports.addChainToAngularJson = addChainToAngularJson;
function exists(host, path, callback) {
    return host.exists(path) ? callback() : host;
}
//# sourceMappingURL=angular-config.js.map